#
# spec file for package python-environ-config
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-environ-config
Version:        23.2.0
Release:        1.2
Summary:        Boilerplate-free configuration with env variables
License:        MIT
URL:            https://github.com/hynek/environ_config
Source:         https://files.pythonhosted.org/packages/source/e/environ-config/environ_config-%{version}.tar.gz
BuildRequires:  %{python_module hatch-fancy-pypi-readme}
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 17.4.0
Conflicts:      python-django-environ
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module attrs >= 17.4.0}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module moto}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module urllib3 < 2}
# /SECTION
%python_subpackages

%description
Boilerplate-free configuration with env variables.

%prep
%setup -q -n environ_config-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md CHANGELOG.md
%{python_sitelib}/environ
%{python_sitelib}/environ_config-%{version}.dist-info

%changelog
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 23.2.0:
  * Type hints for `environ.config()` now allow for arguments
    (e.g. `@environ.config(prefix="")`).
  * `environ.secrets.DirectorySecrets.from_path()` now works when
    loading from `os.environ`.
  * Public APIs now carry type hints (except in-class methods
    like ``AppConfig.from_environ()``).
* Tue May 23 2023 Steve Kowalik <steven.kowalik@suse.com>
- Stick with urllib3 < 2 due to boto.
* Fri Dec  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 22.1.0 (2022-04-02)
  * Deprecations:
  Python 2.7, 3.5, and 3.6 support has been dropped. environ-config now requires Python 3.7 or later.
  * Changes:
  Lazily init the AWS SecretsManager client to make unit testing easier. #25
- Update to 21.2.0 (2021-05-17)
  * Deprecations:
  This is the last release supporting Python versions older than 3.7.
  * Changes:
  Added AWS SecretsManager support. #23
- Update to 21.1.0 (2021-04-14)
  * Backward-incompatible changes:
  none
  * Deprecations:
  none
  * Changes:
  Fixed environment variables’ names when prefix is empty. #14
  Added the optional keyword argument to environ.group() #17
  Added DirectorySecrets secret reader, which can read secrets from a directory of files.
  Useful for Docker or Kubernetes mounted secrets inside a container. #19
* Fri Jul 24 2020 John Vandenberg <jayvdb@gmail.com>
- Add Conflict with python-django-environ
* Tue Jul 21 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v20.1.0
* Sat Mar  9 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v18.2.0
